/**
 * JASMINe
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: QuickVisuModelLocator.as 6492 2010-05-24 09:29:30Z renaultgu $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.quickvisu.cairngorm.model
{
import com.adobe.cairngorm.model.ModelLocator;

import mx.collections.ArrayCollection;
import mx.utils.UIDUtil;

import org.ow2.jasmine.monitoring.eos.quickvisu.cairngorm.business.ConnectTopicDelegate;
import org.ow2.jasmine.monitoring.eos.quickvisu.cairngorm.business.DisconnectTopicDelegate;
import org.ow2.jasmine.monitoring.eos.quickvisu.cairngorm.business.GetJasmineEventDelegate;
import org.ow2.jasmine.monitoring.eos.quickvisu.cairngorm.business.IConnectTopicDelegate;
import org.ow2.jasmine.monitoring.eos.quickvisu.cairngorm.business.IDisconnectTopicDelegate;
import org.ow2.jasmine.monitoring.eos.quickvisu.cairngorm.business.IGetJasmineEventDelegate;

/**
 * @author Guillaume Renault
 */
[Bindable]
public class QuickVisuModelLocator implements ModelLocator
{

    // public
    public static var NO_MESSAGE:uint = 0;

    public static var NEW_MESSAGE:uint = 1;

    public static var DISCONNECTED:uint = 10;

    public static var CONNECTED:uint = 11;

    public var connect:int = 0;

    /**
     * The unique ID of this component
     *
     * @internal
     *   Used to prevent a Cairngorm issue: when a command event is dispatched,
     * every controller that registered this event type receives it, even if
     * located in another module. To prevent this from happening and triggering
     * multiple severe unexpected concurrence bugs, each event dispatched is
     * postfixed with this unique ID.
     */
    public var componentID:String = UIDUtil.createUID();

    // private

    /**
    * Unique instance of this locator.
    */
    private static var model:QuickVisuModelLocator = null;

    //[ArrayElementType(JasmineMessageEventVO)]
    public var jasmineEventObjs:ArrayCollection = null;

    private var stateObj:uint = NO_MESSAGE;

    // delegate unique instances
    private var connectTopicDelegate:IConnectTopicDelegate = null;

    private var disconnectTopicDelegate:IDisconnectTopicDelegate = null;

    private var getJasmineEventDelegate:IGetJasmineEventDelegate = null;

    // functions
    public function QuickVisuModelLocator()
    {
        super();

        if (model != null) {
            throw new Error("Only one QuickVisuModellocator has to be set");
        }
    }

    public static function getInstance() : QuickVisuModelLocator {
        if (QuickVisuModelLocator.model == null) {
            QuickVisuModelLocator.model = new QuickVisuModelLocator();
        }

        return QuickVisuModelLocator.model;
    }

    // setters

    public function set jasmineEvents(message:ArrayCollection) : void {
        this.jasmineEventObjs = message;
    }

    public function set state(state:uint) : void {
        this.stateObj = state;
    }

    // getters

    public function get jasmineEvents():ArrayCollection {
        return this.jasmineEventObjs;
    }

    public function get state() : uint {
        return this.stateObj;
    }


    // getters delegates

    public function getConnectTopicDelegate():IConnectTopicDelegate {
        if (this.connectTopicDelegate == null) {
            this.connectTopicDelegate = new ConnectTopicDelegate();
        }
        return this.connectTopicDelegate;
    }

    public function getDisconnectTopicDelegate():IDisconnectTopicDelegate {
        if (this.disconnectTopicDelegate == null) {
            this.disconnectTopicDelegate = new DisconnectTopicDelegate();
        }
        return this.disconnectTopicDelegate;
    }

    public function getGetJasmineEventDelegate():IGetJasmineEventDelegate {
        if (this.getJasmineEventDelegate == null) {
            this.getJasmineEventDelegate = new GetJasmineEventDelegate();
        }
        return this.getJasmineEventDelegate;
    }


}
}
